@@ -4,5 +4,5 @@ int main(int argn, char **argv, char **envp) {
     setreuid(geteuid(),geteuid());
     setregid(getegid(),getegid());
     argv[0] = SYMPASOAP;
-    execve(SYMPASOAP,argv,envp);
+    return execve(SYMPASOAP,argv,envp);
 }
